Crate vls_policy_derive

Crate vls_policy_derive 

Derive Macros

Optionized
Derives a new struct and a merge function for a given struct. The new struct has the same fields as the original, but each field is wrapped in an Option. See generated merge and resolve_defaults functions for more information. The struct must implement Clone.